==================
openstack masakari
==================

To control and manage masakari operations, the extended `command list
<https://docs.openstack.org/python-masakariclient/latest/cli/index.html>`_
available in openstack command.
